#!/usr/bin/env python
# Copyright 2015 Yelp Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from paasta_tools.utils import list_clusters


def add_subparser(subparsers):
    list_parser = subparsers.add_parser(
        'list-clusters',
        description="Display a list of PaaSTA clusters.",
        help="List PaaSTA clusters.")
    list_parser.set_defaults(command=paasta_list_clusters)


def paasta_list_clusters(args):
    for cluster in list_clusters():
        print cluster
